package com.manage.dao;

import com.manage.entity.Power_Role;
import com.manage.vo.Power_RoleVo;

import java.util.List;

public class Power_RoleMapperImpl implements Power_RoleMapper {
    @Override
    public int deleteByPrimaryKey(Integer roleId) {
        return this.deleteByPrimaryKey(roleId);
    }

    @Override
    public int insert(Power_Role record) {
        return this.insert(record);
    }

    @Override
    public int insertSelective(Power_Role record) {
        return this.insertSelective(record);
    }

    @Override
    public Power_Role selectByPrimaryKey(Integer roleId) {
        return this.selectByPrimaryKey(roleId);
    }

    @Override
    public int updateByPrimaryKeySelective(Power_Role record) {
        return this.updateByPrimaryKeySelective(record);
    }

    @Override
    public int updateByPrimaryKey(Power_Role record) {
        return this.updateByPrimaryKey(record);
    }

    @Override
    public List<Power_RoleVo> findSomeByMore(Power_RoleVo powerRole, Integer roleId,Integer userId) {
        return this.findSomeByMore(powerRole,roleId,userId);
    }

    @Override
    public int getTotal(Power_RoleVo powerRole,Integer userRoleId,Integer userId) {
        return this.getTotal(powerRole,userRoleId,userId);
    }

    @Override
    public List<Power_RoleVo> selectList() {
        return this.selectList();
    }

    @Override
    public Power_Role checkRoleName(String roleName) {
        return this.checkRoleName(roleName);
    }

    @Override
    public List<Power_RoleVo> selectListByPower(Integer roleId,Integer userId) {
        return this.selectListByPower(roleId,userId);
    }

    @Override
    public int SimpleInsert(List<Power_Role> list) {
        return this.SimpleInsert(list);
    }
}
